# Felips-Counter

<p align="center">

<img src="https://user-images.githubusercontent.com/56811005/200190627-ca7691ac-691f-4267-8b14-252982510af0.png" width="200" alt="Felips-Counter logo" >

</p>

![Version](https://img.shields.io/badge/Version-1.0.10-272A34)
![Deploy](https://img.shields.io/github/workflow/status/Blackoutseeker/Felips-Counter-Python/Deploy?label=Deploy)

## Description

### Count your project lines easily!

<br>

## Installation

### Run `pip install felips-counter` in your terminal (as `administrator`).

> **Note**: Make sure the `counter` script or `Python Scripts` is in your `PATH` system variable, in the Environment Variables.

<br>

## Executing

### After installation, open a terminal and run `counter` on your project path.

### Ex.: `C:\Users\PC\Documents\MyProject> counter`

> **Note**: Run `counter -h` or `counter --help` to see all features.

<br>

## `.counterignore` file example:

```
# Paths
/.idea
/__pycache__
/node_modules
/dist
/build
/out
/assets
/coverage
/.vscode

# Files
.gitignore
.env.local

# File extensions
*.lock
*.env
```

<br>

## Development environment

### IDE

<img src="https://user-images.githubusercontent.com/56811005/200193763-af768fe8-cf33-4967-b28b-db89fdba2da3.png" width="120" alt="PyCharm" >

### Package manager

<img src="https://user-images.githubusercontent.com/56811005/200193691-3dc8834b-4ed3-4e3c-b71e-57db0fa61bc0.svg" width="220" alt="PyPI" >

### Version control systems

<img src="https://user-images.githubusercontent.com/56811005/103469908-d5367780-4d49-11eb-8c56-db348eff1989.png" width="400" >

<br>

> **2022 Felipe Pereira**
